package org.drupal.project.recommender.test;

import org.drupal.project.async_command.*;
import org.drupal.project.recommender.RecommenderApp;
import org.junit.Test;

import java.io.File;
import java.sql.SQLException;
import java.util.Properties;

import static junit.framework.Assert.assertTrue;

public class RecommenderTest {

    @Test
    public void testPingMe() throws SQLException {
        // create a pingme command.
        // attention: this drupal connection is the one Drush is using. could be different from the one in the drupalConnection created earlier
        String output = DrupalUtils.executeDrush("async-command", "recommender", "PingMe", "From UnitTest", "string1=Hello");
        System.out.println("Drush output: " + output);

        DrupalConnection drupalConnection = DrupalConnection.create();
        drupalConnection.connect();
        Long id = DrupalUtils.getLong(drupalConnection.queryValue("SELECT max(id) FROM {async_command}"));
        RecommenderApp drupalApp = new RecommenderApp(drupalConnection);
        drupalApp.run();

        // run() closes the drupal connection, so we recreate again.
        drupalConnection.connect(true);
        assertTrue(output.trim().endsWith(id.toString()));
        CommandRecord record = drupalConnection.retrieveCommandRecord(id);
        assertTrue(record.getStatus().equals(AsyncCommand.Status.SUCCESS));
        assertTrue(record.getMessage().endsWith("Hello"));
    }

    //@Test
    public void testRecommender() throws Throwable {
        Properties config = DrupalUtils.loadProperties(DrupalUtils.getConfigPropertiesFile());
        File grouplens = new File(config.getProperty("recommender_test_grouplens_file", "/home/daniel/Development/grouplens_data/100k"));

        DrupalConnection drupalConnection = DrupalConnection.create();
        drupalConnection.connect();

        drupalConnection.update("TRUNCATE TABLE {recommender_preference_staging}");
        BatchUploader insert = new BatchUploader("InsertGroupLens", drupalConnection.getConnection(), "INSERT INTO {recommender_preference_staging} VALUES (?, ?, ?, ?)");
        insert.start();

        insert.accomplish();
        RecommenderApp drupalApp = new RecommenderApp(drupalConnection);
        drupalApp.run();
    }

}
